@@ -1,7 +1,7 @@
 /*
  * _NVRM_COPYRIGHT_BEGIN_
  *
- * Copyright 2006 by NVIDIA Corporation.  All rights reserved.  All
+ * Copyright 2006-2013 by NVIDIA Corporation.  All rights reserved.  All
  * information contained herein is proprietary and confidential to NVIDIA
  * Corporation.  Any use, reproduction, or disclosure without the written
  * permission of NVIDIA Corporation is prohibited.
@@ -29,17 +29,22 @@
 #define __NV_REG_VAR(regkey)  NVreg_##regkey
 
 #if defined(NV_MODULE_PARAMETER)
-#define NV_DEFINE_REG_ENTRY(regkey, default_value) \
-    static NvU32 __NV_REG_VAR(regkey) = (default_value); \
+#define NV_DEFINE_REG_ENTRY(regkey, default_value)        \
+    static NvU32 __NV_REG_VAR(regkey) = (default_value);  \
+    NV_MODULE_PARAMETER(__NV_REG_VAR(regkey))
+#define NV_DEFINE_REG_ENTRY_GLOBAL(regkey, default_value) \
+    NvU32 __NV_REG_VAR(regkey) = (default_value);         \
     NV_MODULE_PARAMETER(__NV_REG_VAR(regkey))
 #else
-#define NV_DEFINE_REG_ENTRY(regkey, default_value) \
+#define NV_DEFINE_REG_ENTRY(regkey, default_value)        \
     static NvU32 __NV_REG_VAR(regkey) = (default_value)
+#define NV_DEFINE_REG_ENTRY_GLOBAL(regkey, default_value) \
+    NvU32 __NV_REG_VAR(regkey) = (default_value)
 #endif
 
 #if defined(NV_MODULE_STRING_PARAMETER)
 #define NV_DEFINE_REG_STRING_ENTRY(regkey, default_value) \
-    char *__NV_REG_VAR(regkey) = (default_value); \
+    char *__NV_REG_VAR(regkey) = (default_value);         \
     NV_MODULE_STRING_PARAMETER(__NV_REG_VAR(regkey))
 #else
 #define NV_DEFINE_REG_STRING_ENTRY(regkey, default_value) \
@@ -339,7 +344,7 @@
 #define __NV_ENABLE_MSI EnableMSI
 #define NV_REG_ENABLE_MSI NV_REG_STRING(__NV_ENABLE_MSI)
 
-#if defined(NVCPU_ARM)
+#if defined(NVCPU_ARM) || defined(NV_VMWARE)
 #define __NV_ENABLE_MSI_DEFAULT 1
 #else
 #define __NV_ENABLE_MSI_DEFAULT 0
@@ -423,6 +428,20 @@
 #define __NV_ENABLE_PCIE_GEN3 EnablePCIeGen3
 #define NV_REG_ENABLE_PCIE_GEN3 NV_REG_STRING(__NV_ENABLE_PCIE_GEN3)
 
+/*
+ * Option: MemoryPoolSize
+ *
+ * Description:
+ *
+ * When set to a non-zero value, this option specifies the size of the
+ * memory pool, given as a multiple of 4KB pages, created on VMware
+ * ESXi to satisfy any system memory allocations requested by the NVIDIA
+ * kernel module.
+ */
+
+#define __NV_MEMORY_POOL_SIZE MemoryPoolSize
+#define NV_REG_MEMORY_POOL_SIZE NV_REG_STRING(__NV_MEMORY_POOL_SIZE)
+
 #if defined(NV_DEFINE_REGISTRY_KEY_TABLE)
 
 /*
@@ -446,6 +465,7 @@ NV_DEFINE_REG_ENTRY(__NV_REGISTER_FOR_ACPI_EVENTS, 1);
 NV_DEFINE_REG_ENTRY(__NV_CHECK_PCI_CONFIG_SPACE, 1);
 NV_DEFINE_REG_ENTRY(__NV_ENABLE_PCIE_GEN3, 0);
 NV_DEFINE_REG_ENTRY(__NV_ENABLE_MSI, __NV_ENABLE_MSI_DEFAULT);
+NV_DEFINE_REG_ENTRY_GLOBAL(__NV_MEMORY_POOL_SIZE, 0);
 
 #if defined(NV_LINUX) || defined(NV_VMWARE)
 NV_DEFINE_REG_STRING_ENTRY(__NV_REGISTRY_DWORDS, NULL);
@@ -481,6 +501,7 @@ nv_parm_t nv_parms[] = {
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_REGISTER_FOR_ACPI_EVENTS),
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_CHECK_PCI_CONFIG_SPACE),
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_ENABLE_PCIE_GEN3),
+    NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_MEMORY_POOL_SIZE),
     {NULL, NULL, NULL}
 };
 
