@@ -1,6 +1,6 @@
  /***************************************************************************\
 |*                                                                           *|
-|*       Copyright 1993-2011 NVIDIA, Corporation.  All rights reserved.      *|
+|*       Copyright 1993-2013 NVIDIA, Corporation.  All rights reserved.      *|
 |*                                                                           *|
 |*     NOTICE TO USER:   The source code  is copyrighted under  U.S. and     *|
 |*     international laws.  Users and possessors of this source code are     *|
@@ -11,7 +11,7 @@
 |*     tion and  internal comments to the code,  notices to the end user     *|
 |*     as follows:                                                           *|
 |*                                                                           *|
-|*       Copyright 1993-2011 NVIDIA, Corporation.  All rights reserved.      *|
+|*       Copyright 1993-2013 NVIDIA, Corporation.  All rights reserved.      *|
 |*                                                                           *|
 |*     NVIDIA, CORPORATION MAKES NO REPRESENTATION ABOUT THE SUITABILITY     *|
 |*     OF  THIS SOURCE  CODE  FOR ANY PURPOSE.  IT IS  PROVIDED  "AS IS"     *|
@@ -366,6 +366,19 @@ typedef unsigned char *PUCHAR;
 
 #endif  // defined(NV_WINDOWS)
 
+/*!
+ * Fixed-point master data types.
+ *
+ * These are master-types represent the total number of bits contained within
+ * the FXP type.  All FXP types below should be based on one of these master
+ * types.
+ */
+typedef NvS16                                                         NvSFXP16;
+typedef NvS32                                                         NvSFXP32;
+typedef NvU16                                                         NvUFXP16;
+typedef NvU32                                                         NvUFXP32;
+
+
 /*!
  * Fixed-point data types.
  *
@@ -373,24 +386,29 @@ typedef unsigned char *PUCHAR;
  * form: Nv<sign>FXP<num_bits_above_radix>_<num bits below radix>.  The actual
  * size of the data type is calculated as num_bits_above_radix +
  * num_bit_below_radix.
+ *
+ * All of these FXP types should be based on one of the master types above.
  */
-typedef NvS16                                                       NvSFXP11_5;
-typedef NvS16                                                       NvSFXP4_12;
-typedef NvS16                                                        NvSFXP8_8;
-typedef NvS32                                                       NvSFXP8_24;
-typedef NvS32                                                      NvSFXP16_16;
-typedef NvS32                                                      NvSFXP20_12;
-typedef NvS32                                                       NvSFXP24_8;
-typedef NvS32                                                       NvSFXP27_5;
-typedef NvS32                                                       NvSFXP29_3;
+typedef NvSFXP16                                                    NvSFXP11_5;
+typedef NvSFXP16                                                    NvSFXP4_12;
+typedef NvSFXP16                                                     NvSFXP8_8;
+typedef NvSFXP32                                                    NvSFXP8_24;
+typedef NvSFXP32                                                   NvSFXP10_22;
+typedef NvSFXP32                                                   NvSFXP16_16;
+typedef NvSFXP32                                                   NvSFXP18_14;
+typedef NvSFXP32                                                   NvSFXP20_12;
+typedef NvSFXP32                                                    NvSFXP24_8;
+typedef NvSFXP32                                                    NvSFXP27_5;
+typedef NvSFXP32                                                    NvSFXP29_3;
 
-typedef NvU16                                                       NvUFXP4_12;
-typedef NvU16                                                        NvUFXP8_8;
-typedef NvU32                                                       NvUFXP8_24;
-typedef NvU32                                                       NvUFXP9_23;
-typedef NvU32                                                      NvUFXP16_16;
-typedef NvU32                                                      NvUFXP20_12;
-typedef NvU32                                                       NvUFXP24_8;
+typedef NvUFXP16                                                    NvUFXP0_16;
+typedef NvUFXP16                                                    NvUFXP4_12;
+typedef NvUFXP16                                                     NvUFXP8_8;
+typedef NvUFXP32                                                    NvUFXP8_24;
+typedef NvUFXP32                                                    NvUFXP9_23;
+typedef NvUFXP32                                                   NvUFXP16_16;
+typedef NvUFXP32                                                   NvUFXP20_12;
+typedef NvUFXP32                                                    NvUFXP24_8;
 
 /*!
  * Utility macros used in converting between signed integers and fixed-point
@@ -408,6 +426,8 @@ typedef NvU32                                                       NvUFXP24_8;
  */
 #define NV_TYPES_UFXP_INTEGER_MAX(x, y)                         (~(BIT((x))-1))
 #define NV_TYPES_UFXP_INTEGER_MIN(x, y)                                     (0)
+#define NV_TYPES_UFXP_ZERO                                                    0
+
 /*!
  * - SIGNED - These are only used for signed.
  */
@@ -419,6 +439,7 @@ typedef NvU32                                                       NvUFXP24_8;
 #define NV_TYPES_SFXP_S32_SIGN_EXTENSION_NEGATIVE(x, y)         (BIT(32-(x))-1)
 #define NV_TYPES_SFXP_INTEGER_MAX(x, y)                            (BIT((x))-1)
 #define NV_TYPES_SFXP_INTEGER_MIN(x, y)                         (~(BIT((x))-1))
+#define NV_TYPES_SFXP_ZERO                                                    0
 
 /*!
  * Conversion macros used for converting between integer and fixed point
