@@ -31,6 +31,34 @@ typedef NvU32 RM_STATUS;
   NVOS_STATUS_IN_RM_STATUS              0x80000000
 */
 
+/*
+    IMPORTANT: When comparing RM_STATUS_LEVEL(_S) against one of these
+    constants, it is important to use '<=' or '>' (rather than '<' or '>=').
+
+    For example. do:
+        if (RM_STATUS_LEVEL(status) <= RM_STATUS_LEVEL_WARN)
+
+    rather than:
+        if (RM_STATUS_LEVEL(status) < RM_STATUS_LEVEL_ERR)
+
+    By being consistent in this manner, it is easier to systematically add
+    additional level constants.  New levels are likely to lower (rather
+    than raise) the severity of _ERR codes.  For example, if we were to add
+    RM_STATUS_LEVEL_RETRY to indicate hardware failures that may be recoverable
+    (e.g. RM_ERR_TIMEOUT_RETRY or RM_ERR_BUSY_RETRY), it would be less severe
+    than RM_STATUS_LEVEL_ERR the level to which these status codes now
+    belong.  Using '<=' and '>' ensures your code is not broken in this case.
+*/
+#define RM_STATUS_LEVEL_OK              0
+#define RM_STATUS_LEVEL_WARN            1
+#define RM_STATUS_LEVEL_ERR             3
+#define RM_STATUS_LEVEL(_S)                                             \
+    ((_S) == RM_OK?                             RM_STATUS_LEVEL_OK:     \
+    ((_S) == RM_ERR_MORE_PROCESSING_REQUIRED?   RM_STATUS_LEVEL_WARN:   \
+    ((_S) != RM_ERROR && (_S) & 0x00000100?     RM_STATUS_LEVEL_WARN:   \
+                                                RM_STATUS_LEVEL_ERR)))
+
+
 #define RM_ERR_CANT_CREATE_CLASS_OBJS   0x00000001
 #define RM_ERR_DMA_IN_USE               0x00000002
 #define RM_ERR_DMA_MEM_NOT_LOCKED       0x00000003
@@ -116,6 +144,8 @@ typedef NvU32 RM_STATUS;
 #define RM_ERR_OUT_OF_RANGE             0x00000063
 #define RM_ERR_NO_VALID_PATH            0x00000064
 #define RM_ERR_CONSTRAINT_VIOLATION     0x00000065
+#define RM_ERR_CYCLE_DETECTED           0x00000066
+#define RM_ERR_RESET_REQUIRED           0x00000067
 
 // Warnings:
 #define RM_WARN_NULL_OBJECT             0x00000100
